@@ -150,52 +150,10 @@ class MurckoRingFragmenter(Fragmenter):
 
         for rix, ring in enumerate(rings):  # Loop through all rings and remove
             edit = RWMol(scaffold.mol)  # Editable molecule
-            editMolBlk = MolToMolBlock(edit, kekulize=False)
-            molA = MolFromMolBlock(editMolBlk)
-            if molA is None:
-                #print('SUPER ERROR')
-                #print(editMolBlk)
-                molA = edit#MolFromMolBlock(editMolBlk)
-            else:
-                SetAromaticity(molA, AROMATICITY_SIMPLE)
-
-            editArmMolBlk = MolToMolBlock(molA, kekulize=False)
+                   
+            molARW = RWMol(scaffold.mol)
             
-            # find all bonds with 4 / trouver toutes les liasons avec 4
-            #matches = re.findall(".{6}(?=  4  \d)", editArmMolBlk)
-            molQTest = MolFromSmarts("[#6,#7,#8;a]")
-            arom_atom_indices_ = molA.GetSubstructMatches(molQTest)#.map((s) => s[0]);
-            arom_atom_indices = sorted(list(map(lambda x: x[0], arom_atom_indices_)))
-            
-            #print('Before setting 11111')
-            #print(editMolBlk)
-            idxV2000 = editArmMolBlk.index("V2000\n")
-            idxV2000ToEnd = editArmMolBlk.index("\n", idxV2000) +1
-            count = 0;
-            for idx_sorted in arom_atom_indices: 
-                while count < idx_sorted: 
-                    count = count + 1
-                    idxV2000ToEnd = editArmMolBlk.index("\n", idxV2000ToEnd) +1
-                                
-                #editArmMolBlk = replace_str_index(editArmMolBlk, idxV2000ToEnd + 56, "1")
-                editArmMolBlk = editArmMolBlk[:idxV2000ToEnd + 56] + "1" + editArmMolBlk[idxV2000ToEnd + 57:]
-                
-            #print(editArmMolBlk)
-            #print(idxV2000ToEnd)
-            #print(editArmMolBlk[idxV2000ToEnd : idxV2000ToEnd + 30])
-
-            editArmMolBlkMarked = editArmMolBlk;#re.sub("(?<=(\d  ){7})0(?=(  \d){4})", "1", editArmMolBlk)
-            
-            #print('Marked')
-            #print(editArmMolBlkMarked)
-            mol11 = MolFromMolBlock(editArmMolBlkMarked)
-            if mol11 == None:
-              print('SUPER ERROR 2')
-              molARW = molA
-            else:
-              molARW = RWMol(mol11)
-            
-            #editAromMolBlkMrk = MolToMolBlock(molARW, kekulize=False)
+            #editAromMolBlkMrk = MolToMolBlock(molARW)
             #print(editAromMolBlkMrk);
             # End edit - molecule / La FIN
             
