@@ -14,7 +14,7 @@ from loguru import logger
 from tqdm.auto import tqdm
 
 from rdkit import __version__ as rdversion
-from rdkit.Chem import rdMolHash, MolToSmiles, rdmolops, MolToMolBlock, MolFromMolBlock, SetAromaticity, AROMATICITY_SIMPLE
+from rdkit.Chem import rdMolHash, MolToSmiles, rdmolops, MolToMolBlock, MolFromMolBlock, MolFromSmarts, SetAromaticity, AROMATICITY_SIMPLE
 from rdkit.Chem.rdMolDescriptors import CalcNumRings
 
 from scaffoldgraph.io import *
@@ -182,10 +182,32 @@ class ScaffoldGraph(nx.DiGraph, ABC):
             miniters=1, dynamic_ncols=True,
         ):
             #print('processing mol');
+            #print(MolToMolBlock(molecule, kekulize=False));
+            
             if molecule is None:
                 continue
             
-            #print(MolToMolBlock(molecule));
+            blkOnMol = MolToMolBlock(molecule, kekulize=True)
+            molQTest = MolFromSmarts("[#6,#7,#8;a]")
+            arom_atom_indices_ = molecule.GetSubstructMatches(molQTest)#.map((s) => s[0]);
+            arom_atom_indices = sorted(list(map(lambda x: x[0], arom_atom_indices_)))
+            
+            #print('Before setting 11111')
+            #print(editMolBlk)
+            idxV2000 = blkOnMol.index("V2000\n")
+            idxV2000ToEnd = blkOnMol.index("\n", idxV2000) +1
+            count = 0;
+            for idx_sorted in arom_atom_indices: 
+                while count < idx_sorted: 
+                    count = count + 1
+                    idxV2000ToEnd = blkOnMol.index("\n", idxV2000ToEnd) +1
+                                
+                #editArmMolBlk = replace_str_index(editArmMolBlk, idxV2000ToEnd + 56, "1")
+                blkOnMol = blkOnMol[:idxV2000ToEnd + 56] + "1" + blkOnMol[idxV2000ToEnd + 57:]
+
+
+            molecule = MolFromMolBlock(blkOnMol)
+            
 
             init_molecule_name(molecule)
             #print('nofrings', CalcNumRings(molecule))
@@ -195,6 +217,8 @@ class ScaffoldGraph(nx.DiGraph, ABC):
                 self.graph['num_filtered'] = self.graph.get('num_filtered', 0) + 1
                 continue
             scaffold = self._initialize_scaffold(molecule, init_args)
+            #print(MolToMolBlock(scaffold.mol, kekulize=False));
+
             if scaffold is not None:
                 self._hierarchy_constructor(scaffold)
 
